==> open-connector-framework-2.5-sources.jar: org/odpi/openmetadata/frameworks/connectors/properties/beans/ExternalSchemaType.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.frameworks.connectors.properties.beans;


import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * ExternalSchemaType links to another schema defined to be reusable in many assets' schema.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public class ExternalSchemaType extends SchemaType
{
    private static final long   serialVersionUID = 1L;

    private SchemaType linkedSchemaType = null;

    /**
     * Default constructor used by subclasses
     */
    public ExternalSchemaType()
    {
        super();
    }


    /**
     * Copy/clone Constructor.
     *
     * @param template template object to copy.
     */
    public ExternalSchemaType(ExternalSchemaType template)
    {
        super(template);

        if (template != null)
        {
            linkedSchemaType = template.getLinkedSchemaType();
        }
    }


    /**
     * Return the list of alternative schema types that this attribute or asset may use.
     *
     * @return list of schema types
     */
    public SchemaType getLinkedSchemaType()
    {
        return linkedSchemaType;
    }


    /**
     * Set up the list of alternative schema types that this attribute or asset may use.
     *
     * @param linkedSchemaType list of schema types
     */
    public void setLinkedSchemaType(SchemaType linkedSchemaType)
    {
        this.linkedSchemaType = linkedSchemaType;
    }


    /**
     * Returns a clone of this object as the abstract SchemaElement class.
     *
     * @return SchemaElement
     */
    @Override
    public SchemaElement cloneSchemaElement()
    {
        return new ExternalSchemaType(this);
    }


    /**
     * Returns a clone of this object as the abstract SchemaType class.
     *
     * @return PrimitiveSchemaType object
     */
    @Override
    public SchemaType cloneSchemaType()
    {
        return new ExternalSchemaType(this);
    }


    /**
     * Standard toString method.
     *
     * @return print out of variables in a JSON-style
     */
    @Override
    public String toString()
    {
        return "ExternalSchemaType{" +
                "linkedSchemaType=" + linkedSchemaType +
                ", formula='" + getFormula() + '\'' +
                ", queries=" + getQueries() +
                ", versionNumber='" + getVersionNumber() + '\'' +
                ", author='" + getAuthor() + '\'' +
                ", usage='" + getUsage() + '\'' +
                ", encodingStandard='" + getEncodingStandard() + '\'' +
                ", namespace='" + getNamespace() + '\'' +
                ", deprecated=" + getIsDeprecated() +
                ", displayName='" + getDisplayName() + '\'' +
                ", description='" + getDescription() + '\'' +
                ", anchorGUID='" + getAnchorGUID() + '\'' +
                ", qualifiedName='" + getQualifiedName() + '\'' +
                ", additionalProperties=" + getAdditionalProperties() +
                ", meanings=" + getMeanings() +
                ", securityTags=" + getSecurityTags() +
                ", searchKeywords=" + getSearchKeywords() +
                ", latestChange='" + getLatestChange() + '\'' +
                ", latestChangeDetails=" + getLatestChangeDetails() +
                ", confidentialityGovernanceClassification=" + getConfidentialityGovernanceClassification() +
                ", confidenceGovernanceClassification=" + getConfidenceGovernanceClassification() +
                ", criticalityGovernanceClassification=" + getCriticalityGovernanceClassification() +
                ", retentionGovernanceClassification=" + getRetentionGovernanceClassification() +
                ", type=" + getType() +
                ", GUID='" + getGUID() + '\'' +
                ", URL='" + getURL() + '\'' +
                ", classifications=" + getClassifications() +
                ", extendedProperties=" + getExtendedProperties() +
                ", headerVersion=" + getHeaderVersion() +
                '}';
    }


    /**
     * Compare the values of the supplied object with those stored in the current object.
     *
     * @param objectToCompare supplied object
     * @return boolean result of comparison
     */
    @Override
    public boolean equals(Object objectToCompare)
    {
        if (this == objectToCompare)
        {
            return true;
        }
        if (!(objectToCompare instanceof ExternalSchemaType))
        {
            return false;
        }
        if (!super.equals(objectToCompare))
        {
            return false;
        }
        ExternalSchemaType that = (ExternalSchemaType) objectToCompare;
        return Objects.equals(getLinkedSchemaType(), that.getLinkedSchemaType());
    }
}

==> open-connector-framework-2.6-sources.jar: org/odpi/openmetadata/frameworks/connectors/properties/beans/ExternalSchemaType.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.frameworks.connectors.properties.beans;


import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * ExternalSchemaType links to another schema defined to be reusable in many assets' schema.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public class ExternalSchemaType extends SchemaType
{
    private static final long   serialVersionUID = 1L;

    private SchemaType linkedSchemaType = null;

    /**
     * Default constructor used by subclasses
     */
    public ExternalSchemaType()
    {
        super();
    }


    /**
     * Copy/clone Constructor.
     *
     * @param template template object to copy.
     */
    public ExternalSchemaType(ExternalSchemaType template)
    {
        super(template);

        if (template != null)
        {
            linkedSchemaType = template.getLinkedSchemaType();
        }
    }


    /**
     * Return the list of alternative schema types that this attribute or asset may use.
     *
     * @return list of schema types
     */
    public SchemaType getLinkedSchemaType()
    {
        return linkedSchemaType;
    }


    /**
     * Set up the list of alternative schema types that this attribute or asset may use.
     *
     * @param linkedSchemaType list of schema types
     */
    public void setLinkedSchemaType(SchemaType linkedSchemaType)
    {
        this.linkedSchemaType = linkedSchemaType;
    }


    /**
     * Returns a clone of this object as the abstract SchemaElement class.
     *
     * @return SchemaElement
     */
    @Override
    public SchemaElement cloneSchemaElement()
    {
        return new ExternalSchemaType(this);
    }


    /**
     * Returns a clone of this object as the abstract SchemaType class.
     *
     * @return PrimitiveSchemaType object
     */
    @Override
    public SchemaType cloneSchemaType()
    {
        return new ExternalSchemaType(this);
    }


    /**
     * Standard toString method.
     *
     * @return print out of variables in a JSON-style
     */
    @Override
    public String toString()
    {
        return "ExternalSchemaType{" +
                "linkedSchemaType=" + linkedSchemaType +
                ", formula='" + getFormula() + '\'' +
                ", queries=" + getQueries() +
                ", versionNumber='" + getVersionNumber() + '\'' +
                ", author='" + getAuthor() + '\'' +
                ", usage='" + getUsage() + '\'' +
                ", encodingStandard='" + getEncodingStandard() + '\'' +
                ", namespace='" + getNamespace() + '\'' +
                ", deprecated=" + getIsDeprecated() +
                ", displayName='" + getDisplayName() + '\'' +
                ", description='" + getDescription() + '\'' +
                ", anchorGUID='" + getAnchorGUID() + '\'' +
                ", qualifiedName='" + getQualifiedName() + '\'' +
                ", additionalProperties=" + getAdditionalProperties() +
                ", meanings=" + getMeanings() +
                ", securityTags=" + getSecurityTags() +
                ", searchKeywords=" + getSearchKeywords() +
                ", latestChange='" + getLatestChange() + '\'' +
                ", latestChangeDetails=" + getLatestChangeDetails() +
                ", confidentialityGovernanceClassification=" + getConfidentialityGovernanceClassification() +
                ", confidenceGovernanceClassification=" + getConfidenceGovernanceClassification() +
                ", criticalityGovernanceClassification=" + getCriticalityGovernanceClassification() +
                ", retentionGovernanceClassification=" + getRetentionGovernanceClassification() +
                ", type=" + getType() +
                ", GUID='" + getGUID() + '\'' +
                ", URL='" + getURL() + '\'' +
                ", classifications=" + getClassifications() +
                ", extendedProperties=" + getExtendedProperties() +
                ", headerVersion=" + getHeaderVersion() +
                '}';
    }


    /**
     * Compare the values of the supplied object with those stored in the current object.
     *
     * @param objectToCompare supplied object
     * @return boolean result of comparison
     */
    @Override
    public boolean equals(Object objectToCompare)
    {
        if (this == objectToCompare)
        {
            return true;
        }
        if (objectToCompare == null || getClass() != objectToCompare.getClass())
        {
            return false;
        }
        if (!super.equals(objectToCompare))
        {
            return false;
        }
        ExternalSchemaType that = (ExternalSchemaType) objectToCompare;
        return Objects.equals(getLinkedSchemaType(), that.getLinkedSchemaType());
    }


    /**
     * Hash of properties
     *
     * @return int
     */
    @Override
    public int hashCode()
    {
        return Objects.hash(super.hashCode(), getLinkedSchemaType());
    }
}
